'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

var _Utils = require('./Utils');

var Utils = _interopRequireWildcard(_Utils);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

/**

ReactSigmaLayoutPlugin is a base class for sigma plugins.

Usage
```
const Dagre = (props) =>
        <ReactSigmaLayoutPlugin
              start={sigma.layouts.dagre.start}
              config={sigma.layouts.dagre.configure}
              stop={() => console.warn("dagre stop not implemented")} />
...
<Dagre/>
```
**/

var ReactSigmaLayoutPlugin = function (_React$Component) {
	(0, _inherits3['default'])(ReactSigmaLayoutPlugin, _React$Component);

	function ReactSigmaLayoutPlugin(props) {
		(0, _classCallCheck3['default'])(this, ReactSigmaLayoutPlugin);

		var _this = (0, _possibleConstructorReturn3['default'])(this, _React$Component.call(this, props));

		_this.render = function () {
			return null;
		};

		_this.state = { running: false };
		return _this;
	}

	ReactSigmaLayoutPlugin.prototype.componentDidMount = function componentDidMount() {
		this._start();
	};

	// Change sigma status only after react rendering complete


	ReactSigmaLayoutPlugin.prototype.componentDidUpdate = function componentDidUpdate(prevProps, prevState) {
		if (prevState.running && !this.state.running) {
			this.props.stop();
			if (this.props.sigma) this.props.sigma.refresh();
		} else if (Utils.propsChanged(prevProps, this.props)) {
			this.props.stop();
			this._start();
		}
	};

	ReactSigmaLayoutPlugin.prototype.componentWillUnmount = function componentWillUnmount() {
		this.props.stop();
	};

	//TODO: Add composition of child components after timeout


	ReactSigmaLayoutPlugin.prototype._start = function _start() {
		var s = this.props.sigma;
		if (!_main2['default'] || !s) return;

		this.props.config(s, ReactSigmaLayoutPlugin._stripOptions(this.props));
		this.props.start(s);

		this.setState({ running: true });
	};

	ReactSigmaLayoutPlugin._stripOptions = function _stripOptions(props) {
		var config = {};
		for (var key in props) {
			if (key !== "start" && key !== "stop" && key !== "config" && key !== "sigma" && key !== "children") config[key] = props[key];
		}return config;
	};

	return ReactSigmaLayoutPlugin;
}(_react2['default'].Component);

ReactSigmaLayoutPlugin.propTypes = {
	config: require('react').PropTypes.func.isRequired,
	start: require('react').PropTypes.func.isRequired,
	stop: require('react').PropTypes.func.isRequired,
	sigma: require('react').PropTypes.any
};
exports['default'] = ReactSigmaLayoutPlugin;
module.exports = exports['default'];